@@ -6,6 +6,8 @@ use swc_common::collections::AHashMap;
 use crate::Versions;
 
 pub static DATA: Lazy<AHashMap<String, Versions>> = Lazy::new(|| {
-    serde_json::from_str(include_str!("compat.json"))
-        .expect("failed parse corejs3-compat data.json")
+    serde_json::from_str(include_str!(
+        "../../../../node_modules/core-js-compat/data.json"
+    ))
+    .expect("failed parse corejs3-compat data.json")
 });
